@@ -4,10 +4,6 @@ __all__ = ["ActorDeadError", "Timeout"]
 class ActorDeadError(Exception):
     """Exception raised when trying to use a dead or unavailable actor."""
 
-    pass
 
-
-class Timeout(Exception):
+class Timeout(Exception):  # noqa: N818
     """Exception raised at future timeout."""
-
-    pass
