@@ -1,9 +1,14 @@
+# ruff: noqa: T201
+
+from __future__ import annotations
+
 import time
+from typing import Any, Callable
 
 from pykka import ActorRegistry, ThreadingActor
 
 
-def time_it(func):
+def time_it(func: Callable[[], Any]) -> None:
     start = time.time()
     func()
     elapsed = time.time() - start
@@ -14,7 +19,7 @@ class SomeObject:
     pykka_traversable = False
     cat = "bar.cat"
 
-    def func(self):
+    def func(self) -> None:
         pass
 
 
@@ -24,33 +29,33 @@ class AnActor(ThreadingActor):
 
     foo = "foo"
 
-    def __init__(self):
+    def __init__(self) -> None:
         super().__init__()
         self.cat = "quox"
 
-    def func(self):
+    def func(self) -> None:
         pass
 
 
-def test_direct_plain_attribute_access():
+def test_direct_plain_attribute_access() -> None:
     actor = AnActor.start().proxy()
     for _ in range(10000):
         actor.foo.get()
 
 
-def test_direct_callable_attribute_access():
+def test_direct_callable_attribute_access() -> None:
     actor = AnActor.start().proxy()
     for _ in range(10000):
         actor.func().get()
 
 
-def test_traversable_plain_attribute_access():
+def test_traversable_plain_attribute_access() -> None:
     actor = AnActor.start().proxy()
     for _ in range(10000):
         actor.bar.cat.get()
 
 
-def test_traversable_callable_attribute_access():
+def test_traversable_callable_attribute_access() -> None:
     actor = AnActor.start().proxy()
     for _ in range(10000):
         actor.bar.func().get()
