@@ -47,7 +47,7 @@ def actor_class(runtime: Runtime) -> type[StaticMethodActor]:
     return StaticMethodActorImpl
 
 
-@pytest.fixture()
+@pytest.fixture
 def proxy(
     actor_class: type[StaticMethodActor],
     events: Events,
